==> lori_sdk-0.7.3.tar.gz: lib/data/models/configurations/internalConfigurations.dart <==
class InternalConfigurations {
  bool hasDynamicTutorial;
  bool useNewCheckout;
  bool useOnlyLocalAssets;
  bool useLegacyCatalogAPI;
  bool useLegacyCommerceAPI;
  bool useLegacyMarketingAPI;
  bool useLegacyRetailerAPI;
  bool supportsDebitCard;
  bool useFilter;
  String urlBaseLori;
  AppProductPageType productPageType;
  bool useNewDealerRanking;
  String minimalAppVersion;
  bool useGeoCatalog;
  String troqueFacilUniqueLink;

  InternalConfigurations(
      {this.hasDynamicTutorial,
      this.useNewCheckout,
      this.useOnlyLocalAssets,
      this.useLegacyCatalogAPI,
      this.useLegacyCommerceAPI,
      this.useLegacyMarketingAPI,
      this.useLegacyRetailerAPI,
      this.supportsDebitCard,
      this.useFilter,
      this.urlBaseLori,
      this.productPageType,
      this.useNewDealerRanking,
      this.minimalAppVersion,
      this.useGeoCatalog,
      this.troqueFacilUniqueLink});

  factory InternalConfigurations.fromJson(Map<String, dynamic> json) =>
      InternalConfigurations(
          hasDynamicTutorial: json['hasDynamicTutorial'] as bool,
          useNewCheckout: json['useNewCheckout'] as bool,
          useOnlyLocalAssets: json['useOnlyLocalAssets'] as bool,
          useLegacyCatalogAPI: json['useLegacyCatalogAPI'] as bool,
          useLegacyCommerceAPI: json['useLegacyCommerceAPI'] as bool,
          useLegacyMarketingAPI: json['useLegacyMarketingAPI'] as bool,
          useLegacyRetailerAPI: json['useLegacyRetailerAPI'] as bool,
          useFilter: json['useFilter'] as bool,
          urlBaseLori: json['urlBaseLori'] as String,
          productPageType: _appProductPageTypeEnumMap[json['productPageType']],
          useNewDealerRanking: json['useNewDealerRanking'] as bool,
          minimalAppVersion: json['minimalAppVersion'] as String,
          useGeoCatalog: json['useGeoCatalog'] as bool,
          troqueFacilUniqueLink: json['troqueFacilUniqueLink'] as String);

  Map<String, dynamic> toJson() => {
        'hasDynamicTutorial': hasDynamicTutorial,
        'useNewCheckout': useNewCheckout,
        'useOnlyLocalAssets': useOnlyLocalAssets,
        'useLegacyCatalogAPI': useLegacyCatalogAPI,
        'useLegacyCommerceAPI': useLegacyCommerceAPI,
        'useLegacyMarketingAPI': useLegacyMarketingAPI,
        'useLegacyRetailerAPI': useLegacyRetailerAPI,
        'useFilter': useFilter,
        'urlBaseLori': urlBaseLori,
        'productPageType': productPageType,
        'useNewDealerRanking': useNewDealerRanking,
        'minimalAppVersion': minimalAppVersion,
        'useGeoCatalog': useGeoCatalog,
        'troqueFacilUniqueLink': troqueFacilUniqueLink
      };
}

enum AppProductPageType { standard, clothing, luxe }

const _appProductPageTypeEnumMap = {
  0: AppProductPageType.standard,
  1: AppProductPageType.clothing,
  2: AppProductPageType.luxe
};

==> lori_sdk-0.9.4.tar.gz: lib/data/models/configurations/internalConfigurations.dart <==
class InternalConfigurations {
  bool hasDynamicTutorial;
  bool useNewCheckout;
  bool useOnlyLocalAssets;
  bool useLegacyCatalogAPI;
  bool useLegacyCommerceAPI;
  bool useLegacyMarketingAPI;
  bool useLegacyRetailerAPI;
  bool supportsDebitCard;
  bool useFilter;
  String urlBaseLori;
  AppProductPageType productPageType;
  bool useNewDealerRanking;
  String minimalAppVersion;
  bool useGeoCatalog;
  String troqueFacilUniqueLink;
  bool isAppTotem;

  InternalConfigurations(
      {this.hasDynamicTutorial,
      this.useNewCheckout,
      this.useOnlyLocalAssets,
      this.useLegacyCatalogAPI,
      this.useLegacyCommerceAPI,
      this.useLegacyMarketingAPI,
      this.useLegacyRetailerAPI,
      this.supportsDebitCard,
      this.useFilter,
      this.urlBaseLori,
      this.productPageType,
      this.useNewDealerRanking,
      this.minimalAppVersion,
      this.useGeoCatalog,
      this.troqueFacilUniqueLink,
      this.isAppTotem});

  factory InternalConfigurations.fromJson(Map<String, dynamic> json) =>
      InternalConfigurations(
        hasDynamicTutorial: json['hasDynamicTutorial'] as bool,
        useNewCheckout: json['useNewCheckout'] as bool,
        useOnlyLocalAssets: json['useOnlyLocalAssets'] as bool,
        useLegacyCatalogAPI: json['useLegacyCatalogAPI'] as bool,
        useLegacyCommerceAPI: json['useLegacyCommerceAPI'] as bool,
        useLegacyMarketingAPI: json['useLegacyMarketingAPI'] as bool,
        useLegacyRetailerAPI: json['useLegacyRetailerAPI'] as bool,
        useFilter: json['useFilter'] as bool,
        urlBaseLori: json['urlBaseLori'] as String,
        productPageType: _appProductPageTypeEnumMap[json['productPageType']],
        useNewDealerRanking: json['useNewDealerRanking'] as bool,
        minimalAppVersion: json['minimalAppVersion'] as String,
        useGeoCatalog: json['useGeoCatalog'] as bool,
        troqueFacilUniqueLink: json['troqueFacilUniqueLink'] as String,
        isAppTotem: json['isAppTotem'] as bool,
      );

  Map<String, dynamic> toJson() => {
        'hasDynamicTutorial': hasDynamicTutorial,
        'useNewCheckout': useNewCheckout,
        'useOnlyLocalAssets': useOnlyLocalAssets,
        'useLegacyCatalogAPI': useLegacyCatalogAPI,
        'useLegacyCommerceAPI': useLegacyCommerceAPI,
        'useLegacyMarketingAPI': useLegacyMarketingAPI,
        'useLegacyRetailerAPI': useLegacyRetailerAPI,
        'useFilter': useFilter,
        'urlBaseLori': urlBaseLori,
        'productPageType': productPageType,
        'useNewDealerRanking': useNewDealerRanking,
        'minimalAppVersion': minimalAppVersion,
        'useGeoCatalog': useGeoCatalog,
        'troqueFacilUniqueLink': troqueFacilUniqueLink,
        'isAppTotem': isAppTotem
      };
}

enum AppProductPageType { standard, clothing, luxe }

const _appProductPageTypeEnumMap = {
  0: AppProductPageType.standard,
  1: AppProductPageType.clothing,
  2: AppProductPageType.luxe
};
